@@ -1,29 +1,62 @@
 #! /bin/sh
-
 # rcsfreeze - assign a symbolic revision number to a configuration of RCS files
-
-#	$Id: rcsfreeze.sh,v 4.6 1993/11/03 17:42:27 eggert Exp $
-
+#
+# Copyright (C) 2010 Thien-Thi Nguyen
+#
+# This file is part of GNU RCS.
+#
+# GNU RCS is free software: you can redistribute it and/or modify it
+# under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 2 of the License, or
+# (at your option) any later version.
+#
+# GNU RCS is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty
+# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+##
+# Usage: rcsfreeze [symbolic-name]
+#
 #       The idea is to run rcsfreeze each time a new version is checked
 #       in. A unique symbolic revision number (C_[number], where number
 #       is increased each time rcsfreeze is run) is then assigned to the most
-#       recent revision of each RCS file of the main trunk.
+#       recent revision of each repository of the main trunk.
 #
 #       If the command is invoked with an argument, then this
 #       argument is used as the symbolic name to freeze a configuration.
 #       The unique identifier is still generated
 #       and is listed in the log file but it will not appear as
-#       part of the symbolic revision name in the actual RCS file.
+#       part of the symbolic revision name in the actual repository.
 #
 #       A log message is requested from the user which is saved for future
 #       references.
 #
-#       The shell script works only on all RCS files at one time.
+#       The shell script works only on all repositories at one time.
 #       It is important that all changed files are checked in (there are
 #       no precautions against any error in this respect).
 #       file names:
 #       {RCS/}.rcsfreeze.ver	version number
 #       {RCS/}.rscfreeze.log	log messages, most recent first
+##
+version='rcsfreeze (GNU RCS) PACKAGE_VERSION
+Copyright (C) 2010 Thien-Thi Nguyen
+Copyright (C) 1990-1995 Paul Eggert
+License GPLv2+; GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>
+This is free software: you are free to change and redistribute it.
+There is NO WARRANTY, to the extent permitted by law.
+
+Written by Stephan v. Bechtolsheim.'
+
+usage ()
+{
+    sed '/^##/,/^##/!d;/^##/d;s/^# //g;s/^#$//g' $0
+}
+
+if [ x"$1" = x--help ] ; then usage ; exit 0 ; fi
+if [ x"$1" = x--version ] ; then echo "$version" ; exit 0 ; fi
 
 PATH=/usr/local/bin:/bin:/usr/bin:/usr/ucb:$PATH
 export PATH
@@ -59,7 +92,7 @@ rcsfreeze: give log message, summarizing changes (end with EOF or single '.')" \
 
 # Stamp the logfile. Because we order the logfile the most recent
 # first we will have to save everything right now in a temporary file.
-TMPLOG=/tmp/rcsfrz$$
+TMPLOG=`mktemp -t` || exit
 trap 'rm -f $TMPLOG; exit 1' 1 2 13 15
 # Now ask for a log message, continously add to the log file
 (
